..
 This work is licensed under a Creative Commons Attribution 3.0 Unported
 License.

 http://creativecommons.org/licenses/by/3.0/legalcode

=============================================
Neutron BGP VPN Interconnection Documentation
=============================================

.. include:: introduction.rst

Introduction videos
===================

The following videos are filmed presentations of talks given during the
Barcelona OpenStack Summit (Oct' 2016). Although they do not cover the work
done since, they can be a good introduction to the project:

* https://www.youtube.com/watch?v=kGW5R8mtmRg
* https://www.youtube.com/watch?v=LCDeR7MwTzE

Contents
========

.. toctree::
   :maxdepth: 2

   user/index
   install/index
   configuration/index
   contributor/index

.. rubric:: Indices and Tables

* :ref:`genindex`
* :ref:`search`
